Brightway2 Whoosh searches
==========================

This package provides database search functionality based on the `Whoosh search library <https://pypi.python.org/pypi/Whoosh/>`_. It is part of the `Brightway2 LCA framework <http://brightwaylca.org>`_. `Online documentation <https://brightway2.readthedocs.org/en/latest/>`_ is available, and the source code is hosted on `Bitbucket <https://bitbucket.org/cmutel/brightway2-whoosh>`_.
